
# reflectionist

A simple CLI app that helps you to track your reflections during your day.


# Why?
Being capable of reflecting helps to understand stressful situations.

Having a different perspective on what happened facilitates to take actions on how to behave to avoid the same feeling again reducing your stress levels and enabling personal growth!

## Reflection questions

The following questions were extracted from my experience at Hyper Island, during the master's in Digital Management.


    1. What happened that affected me?
    2. How did I feel then and now?
    3. What did I learn about myself?




## Installation

Install reflectionist with pip

```bash
  pip install reflectionist
```
    
## Features

- Init environment: `reflectionist init`
- Add reflection: `reflectionist create`
- List reflections: `reflectionist list`
- Describe specific reflection: `reflectionist describe`


## Contributing

Contributions are always welcome! Just open a new issue that I will check it ASAP.

